document.addEventListener("DOMContentLoaded", function () {
    const width = 900;
    const height = 600;
    const svg = d3.select("body").append("svg")
        .attr("width", width)
        .attr("height", height);

    const projection = d3.geoAlbersUsa()
        .translate([width / 2, height / 2]) // translate to the center of the screen
        .scale([1000]); // scale things down to see the entire US

    const colorScale = d3.scaleLinear()
        .domain([0.2, 0.8])
        .range(['white', 'blue']);

    const diversity = {
        'Alabama': 0.457318215587874,
        'Alaska': 0.609523513953008,
        // ... (add data for other states)
    };

    const path = d3.geoPath().projection(projection);

    d3.select('body').append('div').attr('id', 'tooltip').attr('style', 'position: absolute; opacity: 0;');

    d3.json("https://gist.githubusercontent.com/Bradleykingz/3aa5206b6819a3c38b5d73cb814ed470/raw/a476b9098ba0244718b496697c5b350460d32f99/us-states.json", function (error, uState) {
        if (error) throw error;

        svg.selectAll('path')
            .data(uState.features)
            .enter()
            .append('path')
            .attr("d", path)
            .style('fill', (d, i) => colorScale(diversity[uState.features[i].properties["name"]]))
            .attr('class', 'state')
            .on('mouseover', function (event, d) {
                const stateName = uState.features[d].properties["name"];
                const population = statePopulationData[stateName] || "Data not available";

                // Show tooltip on hover
                d3.select('#tooltip')
                    .transition()
                    .duration(200)
                    .style('opacity', 1)
                    .text(`${stateName}: ${population} people`);

                d3.select(this).attr("title", `${stateName}: ${population} people`);
            })
            .on('mouseout', function () {
                // Hide tooltip on mouseout
                d3.select('#tooltip').style('opacity', 0);
            })
            .on('mousemove', function () {
                // Move tooltip with the mouse
                d3.select('#tooltip')
                    .style('left', (d3.event.pageX + 10) + 'px')
                    .style('top', (d3.event.pageY + 10) + 'px');
            })
            .on('click', function (event, d) {
                const stateName = uState.features[d].properties["name"];
                const population = statePopulationData[stateName] || "Data not available";

                // Display population in the console (you can customize this behavior)
                console.log(`${stateName}: ${population} people`);
            });
    });

    var legend = d3.legendColor()
        .scale(colorScale);

    svg.append("g")
        .attr("class", "legendclass")
        .attr("transform", "translate(500,10)")
        .style("position", "absolute")
        .style("top", "500px")
        .style("left", "1000px")
        .call(legend);
});
